function initialize(){
       var center= new google.maps.LatLng(37.27,-76.22);
       var myOptions = {
                zoom: 13,
                center: center,
                mapTypeControl: true,
                mapTypeControlOptions: {style: google.maps.MapTypeControlStyle.DROPDOWN_MENU},
                navigationControl: true,
                mapTypeId: google.maps.MapTypeId.HYBRID
       }     
      var map = new google.maps.Map(document.getElementById("map_canvas"), myOptions);
    
      var pythonCoordinates = [
            new google.maps.LatLng(37.2614684569, -76.2224648775),
            new google.maps.LatLng(37.2495651469, -76.2279774667),
            new google.maps.LatLng(37.2479852997, -76.2336234095),
            new google.maps.LatLng(37.2523673346, -76.2394793827),
            new google.maps.LatLng(37.2591441322, -76.2434092102),
            new google.maps.LatLng(37.2665490336, -76.2436413251),
            new google.maps.LatLng(37.2746218129, -76.2413688314),
            new google.maps.LatLng(37.2794090622, -76.2375818357),
            new google.maps.LatLng(37.2790960505, -76.2298946323),
            new google.maps.LatLng(37.271405151, -76.2243034259),
            new google.maps.LatLng(37.2604542278, -76.2245960156),
            new google.maps.LatLng(37.2479345951, -76.2252755398),
            new google.maps.LatLng(37.2389011191, -76.2266457904),
            new google.maps.LatLng(37.2350852168, -76.2279333004),
            new google.maps.LatLng(37.2356179757, -76.230069477),
            new google.maps.LatLng(37.2390529645, -76.2320543676),
            new google.maps.LatLng(37.2449077953, -76.2327051597),
            new google.maps.LatLng(37.2539190365, -76.2318887586),
            new google.maps.LatLng(37.2625943362, -76.2271468479),
            new google.maps.LatLng(37.2687848725, -76.2195823814),
            new google.maps.LatLng(37.2669234948, -76.2151495432),
            new google.maps.LatLng(37.2579623042, -76.2125579423),
            new google.maps.LatLng(37.2449128856, -76.2123014772),
            new google.maps.LatLng(37.232429117, -76.2128056331),
      ];
      var pythonPolyline = new google.maps.Polyline({
          path: pythonCoordinates,
          strokeColor: '#FF0000',
          strokeOpacity: 1.0,
          strokeWeight: 2,
          editable: true
      });

      pythonPolyline.setMap(map);    
      
      // idt = 120
      var fortranCoordinates120 = [
            new google.maps.LatLng(37.2783, -76.2171),
            new google.maps.LatLng(37.2783, -76.2171),
            new google.maps.LatLng(37.2783, -76.2171),
            new google.maps.LatLng(37.2810, -76.2170),
            new google.maps.LatLng(37.2872, -76.2148),
            new google.maps.LatLng(37.2961, -76.2131),
            new google.maps.LatLng(37.3054, -76.2134),
            new google.maps.LatLng(37.3098, -76.2099),
            new google.maps.LatLng(37.3112, -76.2082),
            new google.maps.LatLng(37.3053, -76.2066),
            new google.maps.LatLng(37.2966, -76.2071),
            new google.maps.LatLng(37.2835, -76.2093),
            new google.maps.LatLng(37.2723, -76.2132),
            new google.maps.LatLng(37.2664, -76.2168),
            new google.maps.LatLng(37.2657, -76.2183),
            new google.maps.LatLng(37.2690, -76.2162),
            new google.maps.LatLng(37.2758, -76.2127),
            new google.maps.LatLng(37.2836, -76.2088),
            new google.maps.LatLng(37.2905, -76.2066),
            new google.maps.LatLng(37.2942, -76.2055),
            new google.maps.LatLng(37.2921, -76.2048),
            new google.maps.LatLng(37.2846, -76.2047),
            new google.maps.LatLng(37.2725, -76.2078),
            new google.maps.LatLng(37.2589, -76.2140),
      ];
      var fortranPolyline120 = new google.maps.Polyline({
          path: fortranCoordinates120,
          strokeColor: 'green',
          strokeOpacity: 1.0,
          strokeWeight: 2,
          editable: true
      });

      fortranPolyline120.setMap(map);   
      
      // idt = 3600
      var fortranCoordinates3600 = [
            new google.maps.LatLng(37.2783, -76.2171),
            new google.maps.LatLng(37.2783, -76.2171),
            new google.maps.LatLng(37.2783, -76.2171),
            new google.maps.LatLng(37.2766, -76.2189),
            new google.maps.LatLng(37.2789, -76.2150),
            new google.maps.LatLng(37.2855, -76.2137),
            new google.maps.LatLng(37.2954, -76.2086),
            new google.maps.LatLng(37.2986, -76.2082),
            new google.maps.LatLng(37.3009, -76.2076),
            new google.maps.LatLng(37.2979, -76.2079),
            new google.maps.LatLng(37.2896, -76.2101),
            new google.maps.LatLng(37.2783, -76.2142),
            new google.maps.LatLng(37.2672, -76.2180),
            new google.maps.LatLng(37.2599, -76.2204),
            new google.maps.LatLng(37.2575, -76.2219),
            new google.maps.LatLng(37.2602, -76.2189),
            new google.maps.LatLng(37.2660, -76.2120),
            new google.maps.LatLng(37.2731, -76.2078),
            new google.maps.LatLng(37.2792, -76.2058),
            new google.maps.LatLng(37.2809, -76.2042),
            new google.maps.LatLng(37.2818, -76.2030),
            new google.maps.LatLng(37.2765, -76.2038),
            new google.maps.LatLng(37.2671, -76.2075),
            new google.maps.LatLng(37.2547, -76.2137),
      ];
      var fortranPolyline3600 = new google.maps.Polyline({
          path: fortranCoordinates3600,
          strokeColor: 'yellow',
          strokeOpacity: 1.0,
          strokeWeight: 2,
          editable: true
      });

      fortranPolyline3600.setMap(map);   

}

    

initialize();