require.config({
	// baseUrl: "/",
	baseUrl: "/research/timcom/particle_tracking",
	paths: {
		"action": "static/javascript/action",
		"model": "static/javascript/model",
		"store": "static/javascript/store",
		"view": "static/javascript/view",
		"dispatcher": "static/javascript/dispatcher/dispatcher",
		"emitter": "static/javascript/emitter",
		"constant": "static/javascript/const/constant",
		"jquery": "static/javascript/lib/jquery-3.1.1.min",
		"jqueryui": "static/javascript/lib/jquery-ui.min",
		"jquerymousewheel": "static/javascript/lib/jquery.mousewheel.min",
		"dateRangeSlider": "static/javascript/lib/jQDateRangeSlider-withRuler-min",
		"vue": "static/javascript/lib/vue",
		"bootstrap": "static/javascript/lib/bootstrap.min",
		"datetimepicker": "static/javascript/lib/bootstrap-datetimepicker.min",
		"moment": "static/javascript/lib/moment-with-locales.min",
		"google": "http://maps.google.com/maps/api/js?sensor=false&.js"
	},
	shim: {
		"google": {
			exports: "google"
		},
		"bootstrap": {
			deps: ['jquery']
		},
		"datetimepicker": {
			deps: ['jquery', 'bootstrap', 'moment']
		},
		"jqueryui": {
            deps: ['jquery']
        },
        "jquerymousewheel": {
            deps: ['jquery']
        },
		"dateRangeSlider": {
			deps: ['jquerymousewheel', 'jqueryui', 'jquery']
		}
	}
});
require(['view/header', 'view/form'], function(Header, Form){
	// Map.init(37.27, -76.22);
});



