define(function(){
	var _emitters = {};
	
	var _register = function(eventType, eventFunc){
		if(!_emitters[eventType]) _emitters[eventType] = [];
		_emitters[eventType].push(eventFunc);
	}

	var _trigger = function(){
		var eventType = Array.prototype.shift.call(arguments),
			eventFuncs = _emitters[eventType];
		for(var i=0, fn; fn = eventFuncs[i++];)
			fn.apply(this, arguments);
	}

	return {
		register: _register,
		trigger: _trigger
	}
});