define(['vue'], function(Vue){
	Vue.component('start-time-calendar', {
		props: ['startTime'],
		template: '<input type="date" class="form-control" v-bind:value="startTime" v-on:change="onChange($event.target.value)" />',
		methods: {
			onChange: function(date){
				this.$emit('calendar-change', date.toString());
			}
		}
	});
});