define(function(){
	var DM = function(lat, lon, status){
		this.lat = lat;
		this.lon = lon;
		this.status = status;
		this.errorMessage = '';
		this.id = (new Date).getTime();
	}

	DM.prototype.getLat = function(){
		return this.lat;
	}

	DM.prototype.getLon = function(){
		return this.lon;
	}

	DM.prototype.getStatus = function(){
		return this.status;
	}

	DM.prototype.setStatus = function(status){
		this.status = status;
	}

	DM.prototype.getErrorMessage = function(){
		return this.errorMessage;
	}

	DM.prototype.setErrorMessage = function(message){
		this.errorMessage = message;
	}

	DM.prototype.getId = function(){
		return this.id;
	}

	return DM;
});