define(function(){
	return {
		TRACK_METHODS: {
			FORWARD_EULER: {
				ID: 'forward_euler',
				TRACK_WAY: 'forward',
				METHOD: 'euler',
				NAME: 'Forward (Euler)'
			},
			FORWARD_RK4: {
				ID: 'forward_rk4',
				TRACK_WAY: 'forward',
				METHOD: 'rk4',
				NAME: 'Forward (Runge-Kutta 4)'
			},
			BACKWARD_EULER: {
				ID: 'backward_euler',
				TRACK_WAY: 'backward',
				METHOD: 'euler',
				NAME: 'Backward (Euler)'
			}
		},
		DATASET_TYPE: {
			ROMS: 'roms',
			TIMCOM: 'timcom'
		}
	}
});