#map_canvas{ width:100%; height:600px; }

.app .radio-inline{padding-top: 3px;}

.app ul{max-height: 411px; overflow-y: auto;}

.app ul li:hover{
	/*background-color: #f0f0f0;*/
}

.app ul span.glyphicon-ok{
	color: green;
	float: right;
}

.app ul span.glyphicon-remove{
	color: red;
	float: right;
}

.app ul span.glyphicon-refresh{
	float: right;
}

.app ul span.glyphicon-minus{
	color: black;
	float: right;
}

.app input.invalid{
	border-color: red;
}